A Portrait Of The Artist As A Young Man (Arc Classics) - Texas Bookman – Wholesale Books, Journals, Gifts & Puzzles
Description: Shop wholesales in art, history, literature & science. Carefully selected overstock.
Keywords: ;9781788283366 ;2212180

- Register |
- Log in |
- Shopping cart (0)

You have no items in your shopping cart.

Information

- About us
- How to Order
- New products
- Recently viewed products
- Sitemap
- Privacy Policy
- Terms of Sale
- Terms of Use

Recently viewed products

- A Portrait Of The Artist As A Young Man (Arc Classics)

Connect With Us

Twitter Facebook

# A Portrait Of The Artist As A Young Man (Arc Classics)

by James Joyce
Arcturus Publishing
Your net price $2.99
Qty:

Pub Date: 2018
Format: Paperback
Pages: 272
Size: 8.00(h) x 5.00(w) x 0.82(t) inches
Case Quantity: 64

ISBN: 9781788283366
TB Code: 2212180
Availability: 849 in stock

James Joyce's first novel follows the life of Stephen Dedalus, an artistic and fiercely individual young man. Along the way, Stephen learns to negotiate the 'snares of the world', to avoid the pitfalls of his dysfunctional family, his terrifying and repressive boarding school and the various beautiful young ladies who capture his heart.

Related products

David Copperfield (Arc Classics) | This Side Of Paradise (Arc Classics) | Chekhov Selected Stories (Arc Classics)
Three Men In A Boat (Arc Classics) |  |